set -x
set -e
sudo cowbuilder update
gbp buildpackage --git-pbuilder --git-pbuilder-options=--source-only-changes
sudo debi
make -B -C /home/hakan/src/avr/nolle07 stampable3.srec
debsign -S
debrelease -S
